import React, { useEffect, useState, useRef } from 'react';
import { BrowserRouter, Routes, Route, Navigate, useLocation, Outlet, useNavigationType, useNavigate } from 'react-router-dom';
import { SidebarProvider } from './context/SidebarContext';
import { AuthProvider, useAuth, setNavigator } from './context/AuthContext';
import { NamespaceProvider, useNamespace } from './context/NamespaceContext';
import { ToastProvider } from './components/ui/toast-notification';
import { HelmetProvider } from 'react-helmet-async';
import { initializeAdvancedAnalytics } from './utils/analytics';
import NamespaceModal from './components/namespaces/namespace/NamespaceModal';
import AuthLoadingScreen from './components/shared/AuthLoadingScreen';
import { preloadCriticalImages } from './utils/imagePreloader';
import { smartPreload } from './utils/imagePreloader';
import { auth } from './firebase/firebase';
import Landing from './pages/landing/Landing.jsx';
import SignIn from './pages/auth/SignIn.jsx';
import SignUp from './pages/auth/SignUp.jsx';
import About from './pages/landing/About.jsx';
import DoneForYou from './pages/landing/DoneForYou.jsx';
import Affiliate from './pages/landing/Affiliate.jsx';
import TermsOfService from './pages/landing/TermsOfService.jsx';
import PrivacyPolicy from './pages/landing/PrivacyPolicy.jsx';
import Header from './components/header/Header.jsx';
import Sidebar from './components/header/Sidebar.jsx';
import Backdrop from './components/header/Backdrop.jsx';
import AlertsService from './components/header/AlertsService.jsx';
import Templates from './pages/templates/Templates.jsx';
import VideoTemplates from './pages/templates/VideoTemplates.jsx';
import StockVideos from './pages/templates/StockVideos.jsx';
import CreateCampaign from './pages/testimonials/CreateCampaign';
import ManageCampaigns from './pages/testimonials/ManageCampaigns';
import CampaignDetails from './pages/testimonials/CampaignDetails';
import EditProfile from './pages/account/EditProfile';
import Account from './pages/account/Account.jsx';
import Support from './pages/account/Support';
import Survey from './pages/testimonials/Survey.jsx';
import Responses from './pages/testimonials/Responses';
import CampaignSettings from './pages/testimonials/CampaignSettings';
import PricingPage from './pages/auth/PricingPage.jsx';
import CheckoutSuccess from './pages/auth/CheckoutSuccess.jsx';
import CheckoutCancel from './pages/auth/CheckoutCancel.jsx';
import CreateNamespace from './pages/namespaces/CreateNamespace.jsx';
import ManageNamespaces from './pages/namespaces/ManageNamespaces.jsx';
import EditNamespace from './pages/namespaces/EditNamespace.jsx';
import ForgotPassword from './pages/auth/ForgotPassword.jsx';
import UpdatePassword from './pages/auth/UpdatePassword.jsx';
import CopyAnalyzer from './pages/tools/CopyAnalyzer.jsx';
import DoneForYouPage from './pages/tools/DoneForYou.jsx';
import CustomTemplateSubmission from './pages/templates/CustomTemplateSubmission.jsx';
import ManageCustomTemplates from './pages/templates/ManageCustomTemplates.jsx';
import CreateTemplates from './pages/admin/CreateTemplates.jsx';
import ManageTemplates from './pages/admin/ManageTemplates.jsx';
import EditTemplate from './pages/admin/EditTemplate.jsx';
import AuthCustomTemplates from './pages/admin/AuthCustomTemplates.jsx';
import AdjustTags from './pages/admin/AdjustTags.jsx';
import TagCounts from './pages/admin/TagCounts.jsx';
import UserManagement from './pages/admin/UserManagement.jsx';
import Admin from './pages/admin/Admin.jsx';
import AdminTemplates from './pages/admin/AdminTemplates.jsx';
import AdminUsers from './pages/admin/AdminUsers.jsx';
import AdminEnterprises from './pages/admin/AdminEnterprises.jsx';
import AdminTools from './pages/admin/AdminTools.jsx';
import AdminStockVideos from './pages/admin/AdminStockVideos.jsx';
import CreateStockVideo from './pages/admin/CreateStockVideo.jsx';
import EditStockVideo from './pages/admin/EditStockVideo.jsx';
import ManageStockVideos from './pages/admin/ManageStockVideos.jsx';
import CreateVideoTemplate from './pages/admin/CreateVideoTemplate.jsx';
import EditVideoTemplate from './pages/admin/EditVideoTemplate.jsx';
import ManageVideoTemplates from './pages/admin/ManageVideoTemplates.jsx';
import DemoTemplates from './pages/landing/DemoTemplates.jsx';
import FacebookAdLanding from './pages/landing/FacebookAdLanding.jsx';
import AccountPricingPage from './pages/account/AccountPricingPage.jsx';
import FreeUsers from './pages/admin/FreeUsers.jsx';
import DeletedUsers from './pages/admin/DeletedUsers.jsx';
import EnterpriseSignUp from './pages/auth/EnterpriseSignUp.jsx';
import EnterpriseSignIn from './pages/auth/EnterpriseSignIn.jsx';
import ManageEnterprises from './pages/admin/ManageEnterprises.jsx';
import CreateEnterprise from './pages/admin/CreateEnterprise.jsx';
import EditEnterprise from './pages/admin/EditEnterprise.jsx';
import ManageEnterprise from './pages/admin/ManageEnterprise.jsx';
import EmailVerificationPending from './pages/auth/EmailVerificationPending.jsx';
import CustomerLists from './pages/admin/CustomerLists.jsx';
import StaticTemplatesPage from './pages/templates/StaticTemplatesPage.jsx';

// This is our main application with immediate loading screen
function AppWithLoading() {
  const [initialLoading, setInitialLoading] = useState(true);
  const [imagesLoaded, setImagesLoaded] = useState(false);
  const [minTimeElapsed, setMinTimeElapsed] = useState(false);
  const [additionalImagesLoaded, setAdditionalImagesLoaded] = useState(false);
  
  // Bypass the initial splash screen on lightweight public routes that shouldn't preload
  const isFacebookAdPage = window.location.pathname === '/ad/facebook';
  const isPublicPricingPage = window.location.pathname === '/pricing';
  

  
  // Effect for controlling the initial loading
  useEffect(() => {
    // Skip the heavy image-preload splash for Facebook ad or public pricing pages
    if (isFacebookAdPage || isPublicPricingPage) {
      setInitialLoading(false);
      return;
    }
    
    // OPTIMIZATION: For landing page (likely unauthenticated users), skip heavy image preloading
    // This makes the landing page load much faster for first-time visitors
    const isLikelyLandingPageVisit = window.location.pathname === '/' && 
                                    !localStorage.getItem('stripe_checkout_initiated') &&
                                    !sessionStorage.getItem('justLoggedIn') &&
                                    !sessionStorage.getItem('googleSignInInProgress');
    
    if (isLikelyLandingPageVisit) {
      console.log('🚀 Using ultra-optimized landing page preloader for public visit...');
      // Ultra-fast for landing page users
      const timer = setTimeout(() => {
        setImagesLoaded(true);
        setMinTimeElapsed(true);
      }, 150); // Reduced from 300ms to 150ms for even faster landing page
      return () => clearTimeout(timer);
    }
    
    // Use smart preloading strategy for authenticated/returning users
    const startPreloading = async () => {
      try {
        console.log('Starting smart image preloading...');
        
        // Use smart preloader that loads critical images first
        await smartPreload(
          // Callback when critical images are loaded
          (criticalImages) => {
            console.log('Critical images loaded, can start app:', criticalImages.length);
            setImagesLoaded(true);
          },
          // Progress callback for additional images
          (loaded, total) => {
            console.log(`Additional images loading: ${loaded}/${total}`);
            if (loaded === total) {
              console.log('All additional images loaded for instant switching');
              setAdditionalImagesLoaded(true);
            }
          }
        );
        
        console.log('Smart preloading completed');
      } catch (error) {
        console.error('Error in smart preloading:', error);
        setImagesLoaded(true); // Continue anyway
      }
    };
    
    // Start preloading images for authenticated users
    startPreloading();
    
    // Reduce minimum loading time for faster experience
    const minTimeTimer = setTimeout(() => {
      console.log('Minimum loading time elapsed');
      setMinTimeElapsed(true);
    }, 800); // Reduced from 1000ms to 800ms
    
    return () => clearTimeout(minTimeTimer);
  }, [isFacebookAdPage, isPublicPricingPage]);
  
  // Only hide loading when both conditions are met
  useEffect(() => {
    // Skip for Facebook ad page - already handled above
    if (isFacebookAdPage || isPublicPricingPage) return;
    
    if (imagesLoaded && minTimeElapsed) {
      console.log('All loading conditions met, hiding loading screen');
      // Instant transition - no delays
      setInitialLoading(false);
    }
  }, [imagesLoaded, minTimeElapsed, isFacebookAdPage, isPublicPricingPage]);
  
  // Track additional images for authenticated users
  useEffect(() => {
    if (additionalImagesLoaded) {
      console.log('🚀 All landing page images preloaded - switching will be instant!');
    }
  }, [additionalImagesLoaded]);
  
  // Show loading screen until ready
  if (initialLoading) {
    console.log('RENDERING LOADER: AppWithLoading initialLoading');
    return <AuthLoadingScreen />;
  }
  
  // Return the complete app with all providers when loading is finished
  return (
    <BrowserRouter>
      <HelmetProvider>
        <AuthProvider>
          <NamespaceProvider>
            <SidebarProvider>
              <ToastProvider>
                <MainApp />
              </ToastProvider>
            </SidebarProvider>
          </NamespaceProvider>
        </AuthProvider>
      </HelmetProvider>
    </BrowserRouter>
  );
}

// Remove the QA environment check since we now use UID check for admin access
function ScrollToTop() {
  const location = useLocation();
  const navigationType = useNavigationType();

  React.useEffect(() => {
    // Don't auto-scroll to top on pricing page to preserve user's scroll position
    const excludedPaths = ['/app/account/pricing', '/app/pricing', '/account/pricing'];
    const shouldSkipScroll = excludedPaths.includes(location.pathname);
    
    if (navigationType === 'PUSH' && !shouldSkipScroll) {
      window.scrollTo({ top: 0, behavior: 'smooth' });
    }
  }, [location, navigationType]);

  return null;
}

// Component to handle navigation events and clean up auth state
function NavigationHandler() {
  const location = useLocation();
  const navigate = useNavigate();
  const { isTransitioning, resetTransitioning, clearLastError, user } = useAuth();
  const [pendingRedirect, setPendingRedirect] = useState(false);
  const prevUserPlanLevelRef = useRef(null);
  const prevUserRef = useRef(null);
  
  // Clean up any stale redirect data on component mount
  useEffect(() => {
    const staleRedirectData = sessionStorage.getItem('auth_redirect_state');
    if (staleRedirectData) {
      console.log('NavigationHandler: Clearing stale auth_redirect_state on mount');
      sessionStorage.removeItem('auth_redirect_state');
    }
  }, []);
  
  // Store the previous plan level to detect downgrades
  useEffect(() => {
    if (user?.planLevel) {
      prevUserPlanLevelRef.current = user.planLevel;
    }
    if (user) {
      prevUserRef.current = user;
    }
  }, [user?.planLevel, user]);
  
  // Preserve PromoteKit referral ID when navigating through the app
  useEffect(() => {
    // Check if we have a PromoteKit referral ID in the URL
    const url = new URL(window.location.href);
    const urlParams = new URLSearchParams(url.search);
    const referralFromUrl = urlParams.get('via');
    
    if (referralFromUrl) {
      console.log('PromoteKit referral ID detected in URL:', referralFromUrl);
      // Store it in sessionStorage to preserve across page navigations
      sessionStorage.setItem('promotekit_referral_id', referralFromUrl);
    }
    
    // If we navigated to a login/signup page, ensure the referral is noted for later use
    if ((location.pathname === '/login' || location.pathname === '/signup' || location.pathname === '/signin') && 
        !url.search.includes('via') && sessionStorage.getItem('promotekit_referral_id')) {
      console.log('Preserving PromoteKit referral through auth flow');
    }
  }, [location.pathname]);
  
  // Debug log when location changes
  useEffect(() => {
    console.log('Navigation occurred to:', location.pathname);
    
    // Check if we're in the middle of signing out or cancelling subscription
    const isSigningOut = sessionStorage.getItem('isSigningOut') === 'true';
    if (isSigningOut) {
      if (location.pathname === '/' || location.pathname === '/app/account/pricing') {
        console.log('Sign out or subscription cancel navigation complete, clearing flag');
        sessionStorage.removeItem('isSigningOut');
      } else if (location.pathname.startsWith('/app')) {
        console.log('Still on app page after sign out/cancellation, forcing redirect');
        navigate('/', { replace: true });
      }
    }
  }, [location.pathname, navigate]);
  
  // Reset auth states when navigation occurs
  useEffect(() => {
    if (isTransitioning) {
      console.log('Auth is in transitioning state, will reset soon...');
      // Increase delay to ensure navigation has fully completed
      const timer = setTimeout(() => {
        resetTransitioning();
        clearLastError();
        console.log('Navigation complete, reset transitioning state');
      }, 2000); // Increase to 2 seconds to ensure navigation completes
      
      return () => clearTimeout(timer);
    }
  }, [location.pathname, isTransitioning, resetTransitioning, clearLastError]);
  
  // Check for stored redirect data from SignIn component
  useEffect(() => {
    // Skip all redirects for Facebook ad page
    if (location.pathname === '/ad/facebook') {
      console.log('On Facebook ad page, skipping NavigationHandler redirects');
      return;
    }
    
    // Check if account deletion is in progress - if so, don't process any redirects
    if (sessionStorage.getItem('accountDeletionInProgress') === 'true') {
      console.log('Account deletion in progress, skipping all NavigationHandler redirects');
      return;
    }
    
    // Check if checkout success is in progress - if so, don't process any redirects
    if (sessionStorage.getItem('checkout_success_in_progress') === 'true') {
      console.log('Checkout success in progress, skipping NavigationHandler redirects');
      return;
    }
    
    // CRITICAL FIX: Check if we're on the success page but have no authenticated user
    // This could happen if someone deleted their account or logged out and stale data is redirecting them
    // BUT: Allow success page access if there are valid Stripe session parameters
    if (location.pathname.startsWith('/success') && !user) {
      // Check for valid Stripe session parameters
      const urlParams = new URLSearchParams(window.location.search);
      const sessionId = urlParams.get('session_id');
      const hasStripeData = sessionId || 
                           localStorage.getItem('stripeSessionId') ||
                           localStorage.getItem('stripe_session_id') ||
                           localStorage.getItem('stripe_checkout_initiated') === 'true';
      
      if (!hasStripeData) {
        console.log('User on success page but not authenticated and no Stripe data - likely stale data, redirecting to home');
        // Clear any stale Stripe data that might be causing the redirect
        localStorage.removeItem('stripeSessionId');
        localStorage.removeItem('stripe_session_id');
        localStorage.removeItem('stripe_checkout_initiated');
        localStorage.removeItem('stripe_checkout_auth_state');
        localStorage.removeItem('stripe_checkout_return_path');
        localStorage.removeItem('post_login_redirect');
        localStorage.removeItem('post_login_session_id');
        sessionStorage.removeItem('in_stripe_checkout_flow');
        sessionStorage.removeItem('stripe_checkout_cancelled');
        
        // Redirect to home page
        navigate('/', { replace: true });
        return;
      } else {
        console.log('User on success page without auth but has valid Stripe data - allowing CheckoutSuccess to handle auth restoration');
        return;
      }
    }
    
    // Check for immediate downgrade scenario first
    const isImmediateDowngrade = sessionStorage.getItem('immediate_downgrade') === 'true';
    if (isImmediateDowngrade && location.pathname.startsWith('/app')) {
      console.log('Immediate downgrade detected! Forcing redirect to pricing page...');
      sessionStorage.removeItem('immediate_downgrade');
      
      // Set pending redirect to prevent flash of incorrect content
      setPendingRedirect(true);
      
      // Immediate redirect without delay
      navigate('/pricing', { replace: true });
      setTimeout(() => setPendingRedirect(false), 100);
      return;
    }
    
    const redirectDataJson = sessionStorage.getItem('auth_redirect_state');
    
    if (redirectDataJson) {
      try {
        const redirectData = JSON.parse(redirectDataJson);
        console.log('Found stored redirect data:', redirectData);
        
        // CRITICAL FIX: Always clear the data immediately to prevent multiple redirects
        sessionStorage.removeItem('auth_redirect_state');
        
        // CRITICAL FIX: Validate redirect data against current user's actual plan level
        // Only use stored redirect data if it's consistent with current user state
        let shouldUseStoredData = true;
        let actualIsPremiumOrPro = false;
        
        if (user) {
          actualIsPremiumOrPro = user.planLevel === 'premium' || user.isEnterprise;
          const storedIsPremiumOrPro = 
            redirectData.isPremiumOrPro || 
            redirectData.planLevel === 'premium' || 
            redirectData.isEnterprise ||
            redirectData.currentPlanLevel === 'premium';
          
          // If stored data conflicts with actual user state, ignore it
          if (storedIsPremiumOrPro !== actualIsPremiumOrPro) {
            console.log('Stored redirect data conflicts with actual user state, ignoring it:', {
              storedIsPremiumOrPro,
              actualIsPremiumOrPro,
              userPlanLevel: user.planLevel,
              storedData: redirectData
            });
            shouldUseStoredData = false;
          }
          
          // ADDITIONAL CHECK: If redirect data is older than 30 seconds, consider it stale
          const dataAge = Date.now() - (redirectData.timestamp || 0);
          if (dataAge > 30000) {
            console.log('Stored redirect data is stale (older than 30s), ignoring it:', {
              dataAge: dataAge + 'ms',
              timestamp: redirectData.timestamp
            });
            shouldUseStoredData = false;
          }
        } else {
          // If no user but we have redirect data, it's likely stale
          console.log('No authenticated user but found redirect data - likely stale, ignoring it');
          shouldUseStoredData = false;
        }
        
        if (!shouldUseStoredData) {
          console.log('Skipping redirect due to data inconsistency or staleness');
          return;
        }
        
        // Enhanced check to ensure we correctly determine premium status
        // CRITICAL: Use actual user state as source of truth, not stored data
        const isPremiumOrPro = actualIsPremiumOrPro;
        
        console.log('Enhanced plan level check from redirect data:', {
          originalIsPremiumOrPro: redirectData.isPremiumOrPro,
          actualIsPremiumOrPro,
          finalIsPremiumOrPro: isPremiumOrPro,
          planLevel: redirectData.planLevel,
          currentPlanLevel: redirectData.currentPlanLevel,
          userPlanLevel: user?.planLevel
        });
        
        // Don't do unnecessary redirects if we're already where we should be
        if (isPremiumOrPro && location.pathname.startsWith('/app')) {
          console.log('Already on app page, no redirect needed');
          return;
        }
        
        if (!isPremiumOrPro && location.pathname === '/pricing') {
          console.log('Already on pricing page, no redirect needed');
          return;
        }
        
        // Set pending redirect to prevent flash of incorrect content
        setPendingRedirect(true);
        
        // Use timeout to ensure navigation happens after UI updates
        const redirectTimeout = isPremiumOrPro ? 100 : 100;
        setTimeout(() => {
          if (isPremiumOrPro) {
            console.log('Redirecting to app based on actual user plan level');
            navigate('/app/', { replace: true });
          } else {
            console.log('Redirecting to pricing based on actual user plan level');
            navigate('/pricing', { replace: true });
          }
          // Reset pending state after navigation
          setPendingRedirect(false);
        }, redirectTimeout);
      } catch (error) {
        console.error('Error parsing redirect data:', error);
        sessionStorage.removeItem('auth_redirect_state');
      }
    }
  }, [location.pathname, navigate, user]);
  
  // Detect plan level downgrade (premium -> basic) and redirect if needed
  useEffect(() => {
    if (user && prevUserPlanLevelRef.current) {
      const prevPlanLevel = prevUserPlanLevelRef.current;
      const currentPlanLevel = user.planLevel;
      
      // Check if user was downgraded from premium to basic
      const wasDowngraded = 
        (prevPlanLevel === 'premium' || user?.isEnterprise) && 
        (currentPlanLevel === 'basic' || currentPlanLevel === 'standard');
      
      if (wasDowngraded && location.pathname.startsWith('/app')) {
        console.log('Plan downgrade detected! Redirecting from app to pricing page...', {
          previousPlan: prevPlanLevel,
          currentPlan: currentPlanLevel,
          path: location.pathname
        });
        
        // Set pending redirect to prevent flash of incorrect content
        setPendingRedirect(true);
        
        // Short delay to ensure UI updates properly
        setTimeout(() => {
          navigate('/pricing', { replace: true });
          setPendingRedirect(false);
        }, 100);
      }
    }
  }, [user, navigate, location.pathname]);
  
  // Improved redirection logic after login - checks subscription level
  useEffect(() => {
    // Skip all redirects for Facebook ad page
    if (location.pathname === '/ad/facebook') {
      console.log('On Facebook ad page, skipping login redirect logic');
      return;
    }
    
    // Check if account deletion is in progress - if so, don't process any redirects
    if (sessionStorage.getItem('accountDeletionInProgress') === 'true') {
      console.log('Account deletion in progress, skipping login redirect logic');
      return;
    }
    
    // CRITICAL FIX: Add a debounce mechanism to prevent rapid successive redirects
    const now = Date.now();
    const lastRedirectTime = sessionStorage.getItem('last_redirect_time');
    if (lastRedirectTime && (now - parseInt(lastRedirectTime)) < 1000) {
      console.log('NavigationHandler: Skipping redirect - too soon after last redirect');
      return;
    }
    
    // Check if we just logged in and are on login page
    if (user && (location.pathname === '/login' || location.pathname === '/signin')) {
      console.log('User is authenticated but still on login page, determining redirect target...', {
        userId: user?.uid,
        planLevel: user?.planLevel,
        subscriptionStatus: user?.subscriptionStatus,
        requiresEmailVerification: user?.requiresEmailVerification,
        emailVerified: user?.emailVerified
      });
      
      // CRITICAL FIX: Check if there's a Google sign-in error flag - if so, don't redirect
      const googleSignInError = sessionStorage.getItem('google_signin_error') === 'true';
      if (googleSignInError) {
        console.log("NavigationHandler: Google sign-in error detected, staying on sign-in page");
        return;
      }
      
      // ADDITIONAL CHECK: Check for any auth errors that should keep user on sign-in page
      const hasAuthError = localStorage.getItem('refrral_auth_error') !== null ||
                          localStorage.getItem('auth_error_timestamp') !== null;
      if (hasAuthError) {
        console.log("NavigationHandler: Auth error detected, staying on sign-in page");
        return;
      }
      
      // Check if user needs email verification first
      const isEnterpriseUser = user?.isEnterpriseUser === true || user?.isEnterprise === true;
      
      if (isEnterpriseUser && auth.currentUser && !auth.currentUser.emailVerified) {
        console.log('NavigationHandler: User needs email verification, redirecting to verify-email page');
        setPendingRedirect(true);
        navigate('/verify-email', { replace: true });
        setTimeout(() => setPendingRedirect(false), 500);
        return;
      }
      
      // Record this redirect attempt
      sessionStorage.setItem('last_redirect_time', now.toString());
      
      // Set pending redirect to prevent flash of incorrect content
      setPendingRedirect(true);
      
      // More robust check for premium subscription
      const isPremiumOrPro = 
        (user?.planLevel === 'premium' || user?.isEnterprise) || 
        (user?.subscriptionStatus?.currentPlanLevel === 'premium');
      
      // Only redirect if we're not already where we should be
      if (isPremiumOrPro && !location.pathname.startsWith('/app')) {
        console.log('Redirecting premium user to dashboard...');
        setPendingRedirect(true);
        navigate('/app/', { replace: true });
        setTimeout(() => {
          setPendingRedirect(false);
          // Clear Google sign-in flag after successful navigation
          sessionStorage.removeItem('googleSignInInProgress');
          // Clear Google sign-up flag after successful navigation
          sessionStorage.removeItem('googleSignUpInProgress');
        }, 500);
      } else if (!isPremiumOrPro && !isEnterpriseUser && location.pathname !== '/pricing' && !location.pathname.startsWith('/success')) {
        // IMPORTANT: Only redirect non-enterprise basic users to public pricing
        // Enterprise users NEVER go to pricing page
        console.log('Redirecting basic non-enterprise user to public pricing...');
        navigate('/pricing', { replace: true });
        // CRITICAL FIX: The redirect is initiated, so we MUST clear the pending state.
        setPendingRedirect(false);
        // Clear Google sign-in flags immediately
        sessionStorage.removeItem('googleSignInInProgress');
        sessionStorage.removeItem('googleSignUpInProgress');
      } else if (isEnterpriseUser && !isPremiumOrPro && !location.pathname.startsWith('/app')) {
        // Enterprise users without premium/pro plans still go to app, not pricing
        console.log('Redirecting enterprise user to app...');
        setPendingRedirect(true);
        navigate('/app/', { replace: true });
        setTimeout(() => {
          setPendingRedirect(false);
          sessionStorage.removeItem('googleSignInInProgress');
          sessionStorage.removeItem('googleSignUpInProgress');
        }, 500);
      } else {
        console.log('NavigationHandler: User already at correct destination, no redirect needed');
        // Clear Google sign-in flag if we're already at the right place
        sessionStorage.removeItem('googleSignInInProgress');
        sessionStorage.removeItem('googleSignUpInProgress');
      }
    }
    
    // Check for the just logged in flag that might be set by SignIn component
    const justLoggedIn = sessionStorage.getItem('justLoggedIn') === 'true';
    if (justLoggedIn && user) {
      console.log('Just logged in flag detected, ensuring proper navigation...', {
        userId: user?.uid,
        planLevel: user?.planLevel,
        subscriptionStatus: user?.subscriptionStatus,
        requiresEmailVerification: user?.requiresEmailVerification,
        emailVerified: user?.emailVerified
      });
      
      // CRITICAL FIX: Check if there's a Google sign-in error flag - if so, don't redirect
      const googleSignInError = sessionStorage.getItem('google_signin_error') === 'true';
      if (googleSignInError) {
        console.log("NavigationHandler: Google sign-in error detected in justLoggedIn, clearing flag and staying on sign-in page");
        sessionStorage.removeItem('justLoggedIn');
        return;
      }
      
      // Check if we're coming from a checkout flow - if so, skip redirect as CheckoutSuccess will handle navigation
      const isComingFromCheckout = localStorage.getItem('stripe_checkout_initiated') === 'true' ||
                                  localStorage.getItem('stripeSessionId') ||
                                  sessionStorage.getItem('in_stripe_checkout_flow') === 'true' ||
                                  window.location.search.includes('session_id=');
      
      if (isComingFromCheckout) {
        console.log('Coming from checkout flow, skipping automatic redirect - CheckoutSuccess will handle navigation');
        // Clear the flag but don't redirect
        sessionStorage.removeItem('justLoggedIn');
        return;
      }
      
      // Check if user needs email verification first
      const isEnterpriseUser = user?.isEnterpriseUser === true || user?.isEnterprise === true;
      
      if (isEnterpriseUser && auth.currentUser && !auth.currentUser.emailVerified) {
        console.log('NavigationHandler: User needs email verification (justLoggedIn), redirecting to verify-email page');
        sessionStorage.removeItem('justLoggedIn');
        setPendingRedirect(true);
        navigate('/verify-email', { replace: true });
        setTimeout(() => setPendingRedirect(false), 500);
        return;
      }
      
      // CRITICAL FIX: Always clear the justLoggedIn flag to prevent multiple redirects
      sessionStorage.removeItem('justLoggedIn');
      
      // Record this redirect attempt
      sessionStorage.setItem('last_redirect_time', now.toString());
      
      // More robust check for premium subscription
      const isPremiumOrPro = 
        (user?.planLevel === 'premium' || user?.isEnterprise) || 
        (user?.subscriptionStatus?.currentPlanLevel === 'premium');
      
      // Only redirect if we're not already where we should be
      if (isPremiumOrPro && !location.pathname.startsWith('/app')) {
        console.log('Redirecting premium user to dashboard...');
        setPendingRedirect(true);
        navigate('/app/', { replace: true });
        setTimeout(() => {
          setPendingRedirect(false);
          // Clear Google sign-in flag after successful navigation
          sessionStorage.removeItem('googleSignInInProgress');
          // Clear Google sign-up flag after successful navigation
          sessionStorage.removeItem('googleSignUpInProgress');
        }, 500);
      } else if (!isPremiumOrPro && !isEnterpriseUser && location.pathname !== '/pricing' && !location.pathname.startsWith('/success')) {
        // IMPORTANT: Only redirect non-enterprise basic users to public pricing
        // Enterprise users NEVER go to pricing page
        console.log('Redirecting basic non-enterprise user to public pricing...');
        navigate('/pricing', { replace: true });
        // CRITICAL FIX: The redirect is initiated, so we MUST clear the pending state.
        setPendingRedirect(false);
        // Clear Google sign-in flags immediately
        sessionStorage.removeItem('googleSignInInProgress');
        sessionStorage.removeItem('googleSignUpInProgress');
      } else if (isEnterpriseUser && !isPremiumOrPro && !location.pathname.startsWith('/app')) {
        // Enterprise users without premium/pro plans still go to app, not pricing
        console.log('Redirecting enterprise user to app...');
        setPendingRedirect(true);
        navigate('/app/', { replace: true });
        setTimeout(() => {
          setPendingRedirect(false);
          sessionStorage.removeItem('googleSignInInProgress');
          sessionStorage.removeItem('googleSignUpInProgress');
        }, 500);
      } else {
        console.log('NavigationHandler: User already at correct destination, no redirect needed');
        // Clear Google sign-in flag if we're already at the right place
        sessionStorage.removeItem('googleSignInInProgress');
        sessionStorage.removeItem('googleSignUpInProgress');
      }
    }
  }, [user, location.pathname, navigate]);
  
  // If we're in a pending redirect state, show AuthLoadingScreen to prevent flashes
  if (pendingRedirect) {
    return <AuthLoadingScreen />;
  }
  
  // Special handling for sign out process
  const isSigningOut = sessionStorage.getItem('isSigningOut') === 'true';
  if (isSigningOut && location.pathname === '/') {
    return <AuthLoadingScreen />;
  }
  
  return null;
}

// Component to initialize the navigator for AuthContext
const InitializeAuthNavigator = () => {
  const navigate = useNavigate();
  useEffect(() => {
    setNavigator(navigate);
    console.log('App.jsx: Auth navigator initialized');
  }, [navigate]);
  return null; // This component does not render anything
};

function RequireAuth({ children }) {
  const { user, loading, signOut } = useAuth();
  const location = useLocation();
  const navigate = useNavigate();
  const [initialDataLoading, setInitialDataLoading] = useState(true);
  const [profileVerified, setProfileVerified] = useState(false);
  
  // Check if user is coming from login or signup
  const isComingFromAuth = 
    location.state?.from?.pathname === '/login' || 
    location.state?.from?.pathname === '/signup' ||
    sessionStorage.getItem('justLoggedIn') === 'true';
  
  // Check if user has no subscription (not premium)
  const hasNoSubscription = user && 
    (user.planLevel !== 'premium' && !user.isEnterprise);
  
  // Check if user is enterprise - ONLY by database flag, NOT by email domain
  const isEnterpriseUser = user?.isEnterpriseUser === true || user?.isEnterprise === true;

  console.log('RequireAuth subscription check:', {
    userId: user?.uid,
    planLevel: user?.planLevel,
    hasNoSubscription,
    isEnterpriseUser,
    path: location.pathname
  });
  
  // Check if we're on special pages that should still work without subscription
  const isOnSurveyPage = location.pathname.includes('/survey/');
  const isOnStockVideosPage = location.pathname === '/app/stockVideos';
  
  // CRITICAL: /app/account/pricing should be accessible to:
  // 1. All non-enterprise users (both with and without subscriptions)
  // 2. NOT accessible to enterprise users (who have enterprise-managed plans)
  // Users with subscriptions need it to manage/upgrade/downgrade their plans
  // Users without subscriptions need it to upgrade to paid plans
  const isOnRestrictedPricingPage = location.pathname === '/app/account/pricing';
  
  // Survey pages and stock videos are allowed without subscription (pricing page has its own logic)
  const isAllowedWithoutSubscription = isOnSurveyPage || isOnStockVideosPage;
  
  // When navigation completes, mark session as logged in
  useEffect(() => {
    if (user && isComingFromAuth) {
      sessionStorage.setItem('justLoggedIn', 'true');
      
      // Set a small timeout to allow data fetching to begin
      const timer = setTimeout(() => {
        setInitialDataLoading(false);
        // Clear the flag after transition is complete
        sessionStorage.removeItem('justLoggedIn');
      }, 1500); // Slightly longer delay for a smoother experience
      
      return () => clearTimeout(timer);
    } else if (user) {
      // If not coming from login, don't show extended loading
      setInitialDataLoading(false);
    }
  }, [user, isComingFromAuth]);

  // Verify user has a valid profile from our server
  useEffect(() => {
    const verifyProfile = async () => {
      if (user && !loading && !profileVerified) {
        // Check if the user has a proper profile
        const hasValidProfile = user.firstName || user.lastName || user.planLevel || user.subscription;
        
        if (!hasValidProfile) {
          console.warn('User account has no valid profile data. Redirecting to login...');
          // Sign out user and redirect to login
          try {
            await signOut(); // Use signOut from context instead of directly calling auth
          } catch (error) {
            console.error('Error signing out user with invalid profile:', error);
          }
          navigate('/login', { state: { 
            error: 'Your account is missing profile data. Please sign in again.'
          }});
          return;
        }
        
        setProfileVerified(true);
      }
    };
    
    verifyProfile();
  }, [user, loading, navigate, profileVerified, signOut]);

  // Improved redirect logic that's more consistent with NavigationHandler
  useEffect(() => {
    // Only run this effect if we have a verified profile and we're not already handling a redirect
    if (!user || loading || !profileVerified || initialDataLoading) {
      return;
    }
    
    // Check if account deletion is in progress - if so, don't redirect
    if (sessionStorage.getItem('accountDeletionInProgress') === 'true') {
      console.log('Account deletion in progress, skipping RequireAuth redirect');
      return;
    }
    
    // IMPORTANT: Don't redirect if user is on success page (they might be completing checkout)
    if (location.pathname.startsWith('/success')) {
      console.log('User is on success page, skipping RequireAuth redirect');
      return;
    }
    
    // Check if there's a specified redirect destination from login
    const redirectDestination = localStorage.getItem('auth_redirect_destination');
    
    if (redirectDestination) {
      // Clear the redirect destination to prevent future redirects
      localStorage.removeItem('auth_redirect_destination');
      console.log('Found redirect destination, navigating to:', redirectDestination);
      navigate(redirectDestination, { replace: true });
      return;
    }
    
    // Skip redirection if NavigationHandler is already handling it
    if (location.pathname.startsWith('/app') && location.pathname !== '/app/account/pricing') {
      console.log('User on app route, checking navigation handling');
    }
    
    // CRITICAL: Basic users should NOT access ANY /app routes EXCEPT allowed ones
    // Redirect them to public pricing page immediately
    if (hasNoSubscription && !isEnterpriseUser && location.pathname.startsWith('/app') && !isAllowedWithoutSubscription) {
      console.log('Basic user trying to access restricted app routes - redirecting to public pricing page...', {
        planLevel: user.planLevel,
        isEnterpriseUser: user.isEnterpriseUser,
        hasNoSubscription,
        path: location.pathname,
        isAllowedWithoutSubscription
      });
      navigate('/pricing', { replace: true });
      return;
    }
  }, [user, loading, profileVerified, hasNoSubscription, isAllowedWithoutSubscription, navigate, initialDataLoading, location.pathname]);

  // Show AuthLoadingScreen when authenticating or loading initial data
  // IMPORTANT: Do NOT show the global AuthLoadingScreen on the public pricing page once
  // the user object exists – this caused the infinite spinner after Google sign-in.
  const isPublicPricing = location.pathname === '/pricing';
  if ((loading || (initialDataLoading && isComingFromAuth && user)) && !isPublicPricing) {
    // Using our custom AuthLoadingScreen instead of the default spinner
    return <AuthLoadingScreen />;
  }

  // If user is not authenticated, redirect to login
  if (!user) {
    // If account deletion is in progress, allow access to landing page
    if (sessionStorage.getItem('accountDeletionInProgress') === 'true' && location.pathname === '/') {
      console.log('Account deletion in progress, allowing access to landing page');
      return children;
    }
    return <Navigate to="/login" state={{ from: location }} replace />;
  }

  // If profile verification is still pending, show AuthLoadingScreen
  if (!profileVerified) {
    // Using our custom AuthLoadingScreen instead of the default spinner
    return <AuthLoadingScreen />;
  }

  // CRITICAL: Check if enterprise user needs email verification before allowing app access
  if (isEnterpriseUser && auth.currentUser && !auth.currentUser.emailVerified) {
    console.log('RequireAuth: Enterprise user with unverified email, redirecting to verification page');
    return <Navigate to="/verify-email" replace />;
  }

  // CRITICAL: Handle access to /app/account/pricing page
  if (isOnRestrictedPricingPage) {
    console.log('RequireAuth: User trying to access restricted pricing page', {
      isEnterpriseUser,
      hasNoSubscription,
      planLevel: user?.planLevel
    });
    
    // Enterprise users should NEVER access /app/account/pricing
    if (isEnterpriseUser) {
      console.log('RequireAuth: Enterprise user trying to access /app/account/pricing, redirecting to app');
      return <Navigate to="/app/" replace />;
    }
    
    // All non-enterprise users (both with and without subscriptions) can access this page
    // Users with subscriptions need it to manage/upgrade/downgrade
    // Users without subscriptions need it to upgrade
    console.log('RequireAuth: Allowing non-enterprise user to access pricing page');
  }

  // CRITICAL: Basic users should already be redirected by the useEffect above
  // This loading screen is no longer needed since basic users won't reach this point
  // Only keep loading for legitimate subscription checks

  return children;
}

function RequireUnauth({ children }) {
  const { user, loading } = useAuth();
  const location = useLocation();
  const navigate = useNavigate();

  // Clear any problematic flags that might cause infinite loading on auth pages
  useEffect(() => {
    // Clear account deletion flag if we're on auth pages (user should be able to sign in)
    if (location.pathname === '/login' || location.pathname === '/signin' || location.pathname === '/signup') {
      sessionStorage.removeItem('accountDeletionInProgress');
      // Also clear any stale auth redirect flags
      const authRedirectFlag = sessionStorage.getItem('auth_redirect_in_progress');
      if (authRedirectFlag === 'true') {
        console.log('Clearing stale auth_redirect_in_progress flag on auth page');
        sessionStorage.removeItem('auth_redirect_in_progress');
      }
      // Clear other potentially problematic flags
      sessionStorage.removeItem('needs_auth_refresh');
      sessionStorage.removeItem('coming_from_signup');
      sessionStorage.removeItem('justLoggedIn');
      console.log('Cleared potentially problematic flags on auth page');
    }
  }, [location.pathname]);

  // Effect to handle redirection after auth state changes
  useEffect(() => {
    if (user && !loading) {
      console.log("RequireUnauth: User is authenticated, checking for redirect...");
      
      // Check if there's a Google sign-in error flag - if so, don't redirect
      const googleSignInError = sessionStorage.getItem('google_signin_error') === 'true';
      if (googleSignInError) {
        console.log("RequireUnauth: Google sign-in error detected, staying on sign-in page");
        return;
      }
      
      // Check if checkout success is in progress - if so, don't redirect
      if (sessionStorage.getItem('checkout_success_in_progress') === 'true') {
        console.log("RequireUnauth: Checkout success in progress, skipping redirect");
        return;
      }
      
      // SPECIAL CASE: Don't redirect away from success page immediately
      // Allow CheckoutSuccess component to handle the flow
      if (location.pathname.startsWith('/success')) {
        console.log("RequireUnauth: User authenticated on success page, allowing CheckoutSuccess to handle the flow");
        return;
      }
      
      // PRIORITY: Check if user needs email verification first (this overrides everything else)
      const isEnterpriseUser = user?.isEnterpriseUser === true || user?.isEnterprise === true;
      
      if (isEnterpriseUser && auth.currentUser && !auth.currentUser.emailVerified) {
        console.log("RequireUnauth: Enterprise user needs email verification, redirecting to verify-email page");
        navigate('/verify-email', { replace: true });
        return;
      }
      
      // CRITICAL FIX: Check user's plan level and enterprise status for proper routing
      const isPremiumOrPro = user.planLevel === 'premium' || user.isEnterprise;
      
      // Check if this is a special context where we should allow pricing page access
      const isFromSettings = location.state?.fromSettings;
      const isFromFeature = location.state?.fromFeature;
      const isFromCreateCampaign = location.state?.fromCreateCampaign;
      const isFromCreateTemplate = location.state?.fromCreateTemplate;
      const isFromTemplates = location.state?.fromTemplates;
      const justSignedUp = localStorage.getItem('just_signed_up') === 'true';
      const comingFromSignup = sessionStorage.getItem('coming_from_signup') === 'true';
      
      // Allow premium users on pricing page only in specific contexts
      const isSpecialContext = isFromSettings || isFromFeature || isFromCreateCampaign || 
                              isFromCreateTemplate || isFromTemplates || justSignedUp || comingFromSignup;
      
      // Determine final destination based on user type and status
      let finalDestination;
      
      if (isEnterpriseUser) {
        // Enterprise users NEVER go to pricing - they go to app
        finalDestination = '/app/';
      } else if (isPremiumOrPro && !isSpecialContext) {
        // Non-enterprise premium users go to app (unless in special context)
        finalDestination = '/app/';
      } else {
        // Basic non-enterprise users go to public pricing
        finalDestination = '/pricing';
      }
      
      // If we're already at the correct destination, don't redirect
      if (location.pathname === finalDestination || 
          (finalDestination === '/app/' && location.pathname.startsWith('/app')) ||
          (finalDestination === '/pricing' && location.pathname === '/pricing')) {
        console.log("RequireUnauth: Already at correct destination, no redirect needed");
        return;
      }
      
      console.log("RequireUnauth: Redirecting based on user type", {
        planLevel: user.planLevel,
        isEnterpriseUser: isEnterpriseUser,
        isPremiumOrPro,
        isSpecialContext,
        currentPath: location.pathname,
        finalDestination
      });
      
      // Direct redirect to final destination - no intermediate stops
      navigate(finalDestination, { replace: true });
    }
  }, [user, loading, location.pathname, navigate, location.state]);

  // Only show loading if we're actually loading auth state, not for stale flags
  if (loading) {
    return <AuthLoadingScreen />;
  }

  // If user is authenticated and we are mid-redirect, show loading screen.
  // Do NOT show this loading screen when we're already on the public pricing page,
  // because it prevents the Pricing page from displaying after Google sign-in.
  const isPublicPricing = location.pathname === '/pricing';
  // Detect if the user will be redirected to the public pricing page (basic, non-enterprise)
  const willRedirectToPricing = user && !user?.isEnterprise && user?.planLevel !== 'premium';
  if (user && !isPublicPricing && !willRedirectToPricing) {
    console.log("RequireUnauth: User authenticated, showing loading screen during redirect");
    return <AuthLoadingScreen />;
  }
  
  // If no user is logged in, show the children (login/signup form)
  return children;
}

// Component to require authentication for email verification page
function RequireAuthVerification({ children }) {
  const { user, loading } = useAuth();
  const location = useLocation();

  // Show loading while checking auth
  if (loading) {
    return <AuthLoadingScreen />;
  }

  // If user is not authenticated, redirect to login
  if (!user) {
    return <Navigate to="/login" state={{ from: location }} replace />;
  }

  // CRITICAL: Only enterprise users should access verification page
  const isEnterpriseUser = user?.isEnterpriseUser === true || user?.isEnterprise === true;
    
  if (!isEnterpriseUser) {
    console.log('RequireAuthVerification: Non-enterprise user trying to access verification page, redirecting to app');
    return <Navigate to="/app/" replace />;
  }

  // User is authenticated enterprise user, allow access to verification page
  return children;
}

// Component to prevent enterprise users from accessing pricing page
function RequireNonEnterprise({ children }) {
  const { user, loading } = useAuth();

  console.log('RequireNonEnterprise: Component called with user:', {
    userId: user?.uid,
    isEnterpriseUser: user?.isEnterpriseUser,
    email: user?.email,
    loading,
    emailVerified: auth.currentUser?.emailVerified,
    hasFirebaseUser: !!auth.currentUser
  });

  // Show loading while checking auth
  if (loading) {
    console.log('RequireNonEnterprise: Auth still loading, showing loading screen');
    return <AuthLoadingScreen />;
  }

  // Check if user is enterprise - ONLY by database flag, NOT by email domain
  const isEnterpriseUser = user?.isEnterpriseUser === true || user?.isEnterprise === true;

  // If Firebase user exists and is enterprise, redirect appropriately
  if (auth.currentUser && isEnterpriseUser) {
    console.log('RequireNonEnterprise: Enterprise user detected (Firebase user exists), checking verification status...', {
      firebaseUserEmail: auth.currentUser.email,
      isEnterpriseUser: user?.isEnterpriseUser,
      emailVerified: auth.currentUser.emailVerified
    });
    
    // Check if enterprise user needs email verification first
    if (!auth.currentUser.emailVerified) {
      console.log('RequireNonEnterprise: Enterprise user needs email verification, redirecting to verify-email page');
      return <Navigate to="/verify-email" replace />;
    } else {
      console.log('RequireNonEnterprise: Verified enterprise user, redirecting to app');
      return <Navigate to="/app/" replace />;
    }
  }

  console.log('RequireNonEnterprise: Non-enterprise user or unauthenticated user, allowing access to public pricing page');
  // Allow all non-enterprise users (both authenticated and unauthenticated) to access public pricing
  return children;
}

// Banner component that uses the ServerStatusContext
function ServerStatusBanner() {
  // Server status removed - no longer showing banner
  return null;
}

function AppLayout() {
  const location = useLocation();
  const { user, loading: authLoading, isProfileLoaded } = useAuth();
  const [showAuthLoading, setShowAuthLoading] = useState(false);
  
  // Check if user just signed in and we should show loading screen longer
  const justLoggedIn = sessionStorage.getItem('justLoggedIn') === 'true';
  const isComingFromAuth = location.state?.from?.pathname === '/login' || 
                          location.state?.from?.pathname === '/signin' ||
                          justLoggedIn;
  
  // For premium users coming from auth, show loading screen for 1 second
  useEffect(() => {
    if (user && isComingFromAuth && (user.planLevel === 'premium' || user.isEnterprise)) {
      setShowAuthLoading(true);
      
      const timer = setTimeout(() => {
        setShowAuthLoading(false);
        // Clear the justLoggedIn flag after the loading period
        sessionStorage.removeItem('justLoggedIn');
      }, 1000);
      
      return () => clearTimeout(timer);
    } else {
      setShowAuthLoading(false);
    }
  }, [user, isComingFromAuth]);
  
  // Special case for main pricing page - no sidebar needed
  if (location.pathname === '/pricing') {
    return <Outlet />;
  }
  
  // Show full-screen loading when auth is loading or profile isn't loaded yet
  // This prevents the sidebar from flashing before auth state is determined
  if (authLoading || (user && !isProfileLoaded)) {
    console.log('AppLayout: Auth loading or profile not loaded, showing full-screen loader');
    return <AuthLoadingScreen />;
  }
  
  // Show extended loading for premium/pro users from auth
  if (showAuthLoading) {
          console.log('AppLayout: Premium user from auth, showing extended loading screen');
    return <AuthLoadingScreen />;
  }
  
  // Render the full layout structure
  console.log('AppLayout: Rendering full layout with sidebar');
  return (
    <SidebarProvider>
      <div className="flex flex-col h-screen bg-white dark:bg-gray-900">
        <AlertsService />
        <div className="flex flex-1 h-screen overflow-hidden">
          <Sidebar />
          <div className="flex-1 flex flex-col h-screen overflow-hidden">
            <Header />
            <Backdrop />
            <div className="flex-1 overflow-y-auto">
              <Outlet />
            </div>
          </div>
        </div>
        <NamespaceModal />
      </div>
    </SidebarProvider>
  );
}

function AppContent() {
  const { user, loading } = useAuth();
  const location = useLocation();
  const navigate = useNavigate();
  const [isRedirecting, setIsRedirecting] = useState(false);

  // Check if the user just signed up
  const isFromSignup = location.state?.from?.pathname === '/signup';
  
  // Much more conservative bot detection - only for obvious crawlers
  const isDefiniteBot = () => {
    if (typeof window === 'undefined') return true;
    
    const userAgent = navigator.userAgent?.toLowerCase() || '';
    
    // Only detect OBVIOUS bots - be very conservative
    const obviousBots = [
      'googlebot', 'bingbot', 'slurp', 'duckduckbot', 'baiduspider',
      'yandexbot', 'facebookexternalhit', 'twitterbot', 'linkedinbot',
      'whatsapp', 'telegrambot', 'crawler', 'spider', 'indexer'
    ];
    
    // Only flag if it's a clear, unambiguous bot
    const isObviousBot = obviousBots.some(bot => userAgent.includes(bot));
    if (isObviousBot) {
      console.log('Obvious bot detected via user agent:', userAgent);
      return true;
    }
    
    // Check for headless automation tools (but be more specific)
    const hasAutomationFlags = !!(
      navigator.webdriver ||
      window.phantom ||
      window.callPhantom ||
      userAgent.includes('headlesschrome') ||
      userAgent.includes('phantomjs') ||
      userAgent.includes('selenium')
    );
    
    if (hasAutomationFlags) {
      console.log('Automation tools detected:', userAgent);
      return true;
    }
    
    return false;
  };
  
  // Track user interaction to distinguish from bots (simplified)
  useEffect(() => {
    const trackInteraction = () => {
      sessionStorage.setItem('has_user_interaction', 'true');
    };
    
    // Listen for ANY user interaction
    ['mousedown', 'keydown', 'touchstart', 'scroll'].forEach(event => {
      document.addEventListener(event, trackInteraction, { once: true, passive: true });
    });
    
    return () => {
      ['mousedown', 'keydown', 'touchstart', 'scroll'].forEach(event => {
        document.removeEventListener(event, trackInteraction);
      });
    };
  }, []);
  
  // Effect to handle authenticated user redirects
  useEffect(() => {
    // Skip all redirects for Facebook ad page
    if (location.pathname === '/ad/facebook') {
      console.log('AppContent: On Facebook ad page, skipping all redirects');
      return;
    }
    
    if (user && !loading && location.pathname === '/') {
      // For authenticated users, ALWAYS redirect - no bot detection needed
      console.log('AppContent: Authenticated user detected, proceeding with redirect');
      
      // Check if account deletion is in progress - if so, don't redirect
      if (sessionStorage.getItem('accountDeletionInProgress') === 'true') {
        console.log('Account deletion in progress, skipping AppContent redirect');
        return;
      }
      
      // Minimal delay for authenticated users
      const redirectDelay = 100;
      
      setIsRedirecting(true);
      
      // Check if user is enterprise - ONLY by database flag, NOT by email domain
      const isEnterpriseUser = user.isEnterpriseUser === true || user.isEnterprise === true;
      
      // PRIORITY: Check if enterprise user needs email verification first
      if (isEnterpriseUser && auth.currentUser && !auth.currentUser.emailVerified) {
        console.log('AppContent: Enterprise user needs email verification, redirecting to verify-email page');
        setTimeout(() => navigate('/verify-email', { replace: true }), redirectDelay);
        return;
      }
      
      // Determine redirect destination based on user type and plan
      const isPremiumOrPro = user.planLevel === 'premium' || user.isEnterprise;
      
      // Set a timeout to ensure smooth transition
      const timer = setTimeout(() => {
        let destination;
        
        if (isEnterpriseUser) {
          // Enterprise users NEVER go to pricing - they go directly to app
          destination = '/app/';
          console.log('AppContent: Enterprise user detected, redirecting to app');
        } else if (isPremiumOrPro) {
          // Non-enterprise premium users go to app
          destination = '/app/';
          console.log('AppContent: Premium user detected, redirecting to app');
        } else {
          // Basic non-enterprise users go to public pricing page
          destination = '/pricing';
          console.log('AppContent: Basic user detected, redirecting to public pricing');
        }
        
        navigate(destination, { replace: true });
      }, redirectDelay);
      
      return () => clearTimeout(timer);
    }
    
    // Handle unauthenticated users - MUCH more conservative approach
    if (!user && !loading && location.pathname === '/') {
      console.log('AppContent: Unauthenticated user on root path, checking for auth errors...');
      
      // ONLY prevent redirects for OBVIOUS bots, not legitimate users
      if (isDefiniteBot()) {
        console.log('AppContent: Obvious bot/crawler detected, skipping redirects for SEO');
        return;
      }
      
      // Check for very recent Google sign-in errors (only 15 seconds now)
      const googleSignInError = sessionStorage.getItem('google_signin_error') === 'true';
      const googleSignInTimestamp = sessionStorage.getItem('google_signin_error_timestamp');
      
      if (googleSignInError) {
        // Check if the error is very recent (within 15 seconds)
        if (googleSignInTimestamp) {
          const errorAge = Date.now() - parseInt(googleSignInTimestamp);
          if (errorAge < 15000) { // Only 15 seconds for Google sign-in errors
            console.log('AppContent: Very recent Google sign-in error detected, redirecting to sign-in page');
            // Add small delay to ensure this isn't automated
            setTimeout(() => navigate('/signin', { replace: true }), 300);
            return;
          } else {
            console.log('AppContent: Stale Google sign-in error, clearing it');
            sessionStorage.removeItem('google_signin_error');
            sessionStorage.removeItem('google_signin_error_timestamp');
          }
        } else {
          // No timestamp means it's old, clear it
          console.log('AppContent: Google sign-in error without timestamp, clearing it');
          sessionStorage.removeItem('google_signin_error');
          sessionStorage.removeItem('google_signin_error_timestamp');
        }
      }
      
      // Check for any stored auth errors - but only VERY recent ones (within 15 seconds)
      const authError = localStorage.getItem('refrral_auth_error');
      const authErrorTimestamp = localStorage.getItem('auth_error_timestamp');
      
      if (authError && authErrorTimestamp) {
        const errorAge = Date.now() - parseInt(authErrorTimestamp);
        const isVeryRecentError = errorAge < 15000; // Reduced to 15 seconds
        
        if (isVeryRecentError) {
          console.log('AppContent: Very recent auth error detected, redirecting to sign-in page');
          // Add small delay to ensure this isn't automated
          setTimeout(() => navigate('/signin', { replace: true }), 300);
          return;
        } else {
          console.log('AppContent: Found stale auth error, clearing it instead of redirecting');
          // Clear stale auth errors
          localStorage.removeItem('refrral_auth_error');
          localStorage.removeItem('auth_error_timestamp');
          // Also clear any other stale auth data
          const authErrorKeys = [
            'auth_error', 
            'stripe_auth_error',
            'refrral_auth_error_key',
            'auth_error_storage_key'
          ];
          authErrorKeys.forEach(key => {
            localStorage.removeItem(key);
            sessionStorage.removeItem(key);
          });
        }
      } else if (authError || authErrorTimestamp) {
        // If we have one but not the other, it's likely stale - clear it
        console.log('AppContent: Found incomplete auth error data, clearing stale data');
        localStorage.removeItem('refrral_auth_error');
        localStorage.removeItem('auth_error_timestamp');
      }
      
      // For clean sessions (most legitimate users), allow normal access to home page
      console.log('AppContent: Clean session detected, allowing normal access to home page');
      // Clear any potentially stale auth-related flags that could cause future redirects
      sessionStorage.removeItem('google_signin_error');
      sessionStorage.removeItem('google_signin_error_timestamp');
      localStorage.removeItem('refrral_auth_error');
      localStorage.removeItem('auth_error_timestamp');
    }
  }, [user, loading, location.pathname, navigate, isFromSignup]);

  if (loading || isRedirecting) {
    // Using our custom AuthLoadingScreen instead of the default spinner
    return <AuthLoadingScreen />;
  }

  // Redirect authenticated users based on their origin
  if (user && location.pathname === '/') {
    return <AuthLoadingScreen />;
  }

  return <Landing />;
}

// Component to handle auth restoration after Stripe checkout
function StripeAuthHandler() {
  const { user, loading } = useAuth();
  const [isRestoring, setIsRestoring] = useState(false);
  
  useEffect(() => {
    // Skip if already logged in or still loading
    if (user || loading || isRestoring) {
      return;
    }
    
    const checkStripeAuthNeeded = async () => {
      try {
        // Check if auto-login is needed after returning from Stripe
        const autoLoginNeeded = localStorage.getItem('stripe_auto_login_needed') === 'true';
        
        if (autoLoginNeeded) {
          console.log('Auto-login needed after Stripe checkout');
          setIsRestoring(true);
          
          // Get saved credentials
          const email = localStorage.getItem('stripe_auth_email');
          const uid = localStorage.getItem('stripe_auth_uid');
          
          if (!email || !uid) {
            console.error('Missing saved credentials for auto-login');
            localStorage.removeItem('stripe_auto_login_needed');
            return;
          }
          
          console.log('Found credentials for auto-login:', { email, uid });
          
          // Get auth and FirebaseAuth modules
          const { auth } = await import('./firebase/firebase');
          const { signInWithEmailAndPassword, setPersistence, browserLocalPersistence } = await import('firebase/auth');
          
          // Set persistence to LOCAL
          await setPersistence(auth, browserLocalPersistence);
          
          // Check if already signed in
          if (auth.currentUser?.uid === uid) {
            console.log('Already signed in with correct user, refreshing token');
            await auth.currentUser.getIdToken(true);
          } else {
            console.log('Attempting auto sign-in for user:', email);
            
            // Attempt auto-login using Firebase SDK
            try {
              // We don't have the password, so we can only restore if the user is still in Firebase cache
              // Otherwise, we'll rely on the AuthContext to handle redirecting to login
              
              // If currentUser exists but is different, sign out first
              if (auth.currentUser && auth.currentUser.uid !== uid) {
                await auth.signOut();
              }
              
              // If we get here, we need to redirect to success page with session ID
              const sessionId = localStorage.getItem('stripe_session_id');
              if (sessionId) {
                console.log('Redirecting to success page with session ID:', sessionId);
                window.location.href = `/success?session_id=${sessionId}`;
              }
            } catch (loginError) {
              console.error('Auto login failed:', loginError);
              // This is expected in most cases since we don't have the password
              // User will need to log in manually
            }
          }
          
          // Clear the flag regardless of success
          localStorage.removeItem('stripe_auto_login_needed');
        }
      } catch (error) {
        console.error('Error in StripeAuthHandler:', error);
      } finally {
        setIsRestoring(false);
      }
    };
    
    checkStripeAuthNeeded();
  }, [user, loading, isRestoring]);
  
  return null; // This component doesn't render anything
}

// Main application component (without the splash screen)
function MainApp() {
  // This call to useAuth() should now work as MainApp is a child of AuthProvider
  const { user, loading, isProfileLoaded, isAdmin, lastError, isTransitioning } = useAuth(); 
  const location = useLocation(); // This also needs BrowserRouter as an ancestor

  // Initialize analytics when app starts
  useEffect(() => {
    // OPTIMIZATION: Defer analytics initialization to not block rendering
    const initAnalytics = () => {
      const pageName = location.pathname === '/' ? 'home' : location.pathname.replace('/', '');
      initializeAdvancedAnalytics(pageName);
    };
    
    // For landing page users, defer analytics to prioritize rendering
    if (location.pathname === '/' && !user) {
      setTimeout(initAnalytics, 100); // Short delay for landing page
    } else {
      initAnalytics(); // Immediate for authenticated users
    }
  }, [])

  // Track page changes for analytics
  useEffect(() => {
    const pageName = location.pathname === '/' ? 'home' : location.pathname.replace('/', '');
    if (window.advocacyLabAnalytics) {
      window.advocacyLabAnalytics.currentPage = pageName;
      console.log(`📍 Page changed to: ${pageName}`);
    }
  }, [location.pathname]);

  // OPTIMIZED: Special handling for survey pages and Facebook ad page - bypass most loading checks
  const isSurveyPage = location.pathname.startsWith('/survey/');
  const isFacebookAdPage = location.pathname === '/ad/facebook';

  // Simplified loading condition - only check essential flags
  const googleSignInInProgress = sessionStorage.getItem('googleSignInInProgress') === 'true';
  const googleSignUpInProgress = sessionStorage.getItem('googleSignUpInProgress') === 'true';
  const hasAuthError = localStorage.getItem('refrral_auth_error') !== null;
  
  // NEVER show the global AuthLoadingScreen while rendering the public pricing page.
  // Doing so caused the apparent "infinite spinner" the user is reporting because
  // the overlay stayed mounted even after navigation completed.
  const isPublicPricing = location.pathname === '/pricing';

  const showLoadingScreen = !isSurveyPage &&
    !isFacebookAdPage &&
    !hasAuthError &&
    loading &&
    // Skip showing the loader if we're on the public pricing route
    !isPublicPricing &&
    (user && !isProfileLoaded && location.pathname !== '/new-signup') &&
    // CRITICAL: Don't show loading during Google sign-in/sign-up process OR during transitions
    !googleSignInInProgress && !googleSignUpInProgress && !isTransitioning;

  // IMPORTANT: All hooks must be called unconditionally before any returns
  // Debugging logs
  useEffect(() => {
    console.log('App.jsx - Auth State:', { 
      user, 
      loading, 
      isProfileLoaded, 
      isAdmin, 
      lastError,
      path: location.pathname,
      isSurveyPage,
      googleSignInInProgress, 
      googleSignUpInProgress,
      hasAuthError,
      isTransitioning
    });
  }, [user, loading, isProfileLoaded, isAdmin, lastError, location.pathname, isSurveyPage, googleSignInInProgress, googleSignUpInProgress, hasAuthError, isTransitioning]);

  // AFTER all hooks are called, we can have conditional returns
  if (showLoadingScreen) {
    return <AuthLoadingScreen />;
  }

  // MainApp now returns its core content directly
  return (
    <>
      <ScrollToTop />
      <NavigationHandler />
      <InitializeAuthNavigator />
      <StripeAuthHandler />
      <Routes>
        <Route path="/survey/:id" element={<Survey />} />
        <Route path="/" element={<AppContent />} />
        <Route path="/about" element={<About />} />
        <Route path="/done-for-you" element={<DoneForYou />} />
        <Route path="/affiliate" element={<Affiliate />} />
        <Route path="/demo-templates" element={<DemoTemplates />} />
        <Route path="/ad/facebook" element={<FacebookAdLanding />} />
        <Route path="/terms" element={<TermsOfService />} />
        <Route path="/privacy" element={<PrivacyPolicy />} />
        <Route path="/templates" element={<StaticTemplatesPage />} />
        <Route path="/login" element={<RequireUnauth><SignIn /></RequireUnauth>} />
        <Route path="/signin" element={<RequireUnauth><SignIn /></RequireUnauth>} />
        <Route path="/forgot-password" element={<RequireUnauth><ForgotPassword /></RequireUnauth>} />
        <Route path="/update-password" element={<UpdatePassword />} />
        <Route path="/signup" element={<RequireUnauth><SignUp /></RequireUnauth>} />
        <Route path="/enterprise/signup" element={<RequireUnauth><EnterpriseSignUp /></RequireUnauth>} />
        <Route path="/enterprise/signin" element={<RequireUnauth><EnterpriseSignIn /></RequireUnauth>} />
        <Route path="/verify-email" element={<RequireAuthVerification><EmailVerificationPending /></RequireAuthVerification>} />
        <Route path="/pricing" element={<RequireNonEnterprise><PricingPage /></RequireNonEnterprise>} />
        <Route path="/success" element={<CheckoutSuccess />} />
        <Route path="/cancel" element={<CheckoutCancel />} />
        <Route path="/app" element={<RequireAuth><AppLayout /></RequireAuth>}>
          <Route index element={<Templates />} />
          <Route path="videoTemplates" element={<VideoTemplates />} />
          <Route path="stockVideos" element={<StockVideos />} />
          <Route path="copyAnalyzer" element={<CopyAnalyzer />} />
          <Route path="doneForYou" element={<DoneForYouPage />} />
          <Route path="CustomTemplateSubmission" element={<CustomTemplateSubmission />} />
          <Route path="manageCustomTemplates" element={<ManageCustomTemplates />} />
          <Route path="campaigns/new" element={<CreateCampaign />} />
          <Route path="campaigns/:id/responses" element={<Responses />} />
          <Route path="campaigns/:id/settings" element={<CampaignSettings />} />
          <Route path="campaigns/:id" element={<CampaignDetails />} />
          <Route path="campaigns" element={<ManageCampaigns />} />
          <Route path="profile" element={<EditProfile />} />
          <Route path="account" element={<Account />} />
          <Route path="account/pricing" element={<AccountPricingPage />} />
          <Route path="support" element={<Support />} />
          <Route path="namespaces/create" element={<CreateNamespace />} />
          <Route path="namespaces/manage" element={<ManageNamespaces />} />
          <Route path="namespaces/edit/:id" element={<EditNamespace />} />
          <Route path="private/admin" element={<Admin />} />
          <Route path="private/admin/templates" element={<AdminTemplates />} />
          <Route path="private/admin/stock-videos" element={<AdminStockVideos />} />
          <Route path="private/admin/users" element={<AdminUsers />} />
          <Route path="private/admin/customer-lists" element={<CustomerLists />} />
          <Route path="private/admin/enterprises" element={<AdminEnterprises />} />
          <Route path="private/admin/tools" element={<AdminTools />} />
          <Route path="private/createTemplate" element={<CreateTemplates />} />
          <Route path="private/manageTemplates" element={<ManageTemplates />} />
          <Route path="private/editTemplate/:templateId" element={<EditTemplate />} />
          <Route path="private/createStockVideo" element={<CreateStockVideo />} />
          <Route path="private/editStockVideo/:id" element={<EditStockVideo />} />
          <Route path="private/manageStockVideos" element={<ManageStockVideos />} />
          <Route path="private/createVideoTemplate" element={<CreateVideoTemplate />} />
          <Route path="private/editVideoTemplate/:videoTemplateId" element={<EditVideoTemplate />} />
          <Route path="private/manageVideoTemplates" element={<ManageVideoTemplates />} />
          <Route path="private/authCustomTemplates" element={<AuthCustomTemplates />} />
          <Route path="private/adjustTags" element={<AdjustTags />} />
          <Route path="private/tagCounts" element={<TagCounts />} />
          <Route path="private/userManagement" element={<UserManagement />} />
          <Route path="private/freeUsers" element={<FreeUsers />} />
          <Route path="private/deletedUsers" element={<DeletedUsers />} />
          <Route path="private/manageEnterprises" element={<ManageEnterprises />} />
          <Route path="private/createEnterprise" element={<CreateEnterprise />} />
          <Route path="private/editEnterprise/:id" element={<EditEnterprise />} />
          <Route path="private/manageEnterprise/:id" element={<ManageEnterprise />} />
        </Route>
        <Route path="*" element={<Navigate to="/" replace />} />
      </Routes>
    </>
  );
}

// App is now a simple wrapper around our AppWithLoading component
function App() {
  return <AppWithLoading />;
}

export default App;